<div class="row index-intro-2 unpadded divider">
    <img src="http://placehold.it/1000x346/515254/ffffff" class="background" alt="">
    <div class="small-12 content columns unpadded">
        <div class="small-12 columns black-wrap">
            <h2>My fabulous introduction title</h2>
        </div>
        <div class="white-on-black small-12 medium-3 columns offset-by-nine">
            <ul>
                <li class="icon-android bullet">Sample row with an Android icon</li>
                <li>This is a row sample</li>
                <li>Another row sample</li>
                <li>Row sample ?</li>
                <li>Row sample.</li>
                <li>Then another row sample</li>
                <li>Row sample again</li>
                <li>Not a row sample at all</li>
            </ul>
        </div>
        <div class="small-12 columns black-wrap">
            <h4>This is an optionnal bottomline introduction</h4>
        </div>
    </div>
</div>
