{% extends "contact_form/base.html" %}
{% load i18n %}

{% block content %}
    <h2>{% trans "Demande de devis" %}</h2>
    
    <p>{% trans "Thank you for your message, we will get back to you quickly !" %}</p>
{% endblock %}

