{% extends "contact_form/base.html" %}
{% load i18n crispy_forms_tags %}
{% block title %}{% trans "Contact" %}{% endblock %}

{% block contact_form_container %}
    <div class="head">
        <h2>{% trans "Contact" %}</h2>
    </div>
    {% crispy form %}
{% endblock %}
