{% load i18n %}
<hr class="big">
<div class="pagination-centered">
    <ul class="pagination">
    {% comment %}<li class="index">
        {% blocktrans with current_page=page.number total_page=page.paginator.num_pages %}Page {{ current_page }} of {{ total_page }}{% endblocktrans %}
    </li>{% endcomment %}

    {% if page.has_previous %}
    <li class="arrow previous">
        <a href="?page={{ page.previous_page_number }}{{ GET_string }}"
        title="{% trans "More recent entries" %}">&laquo;</a>
    </li>
    {% endif %}

    {% for page_number in begin %}
    <li class="page {% ifequal page.number page_number %}current unavailable{% endifequal %}">
        {% ifequal page.number page_number %}
        <strong>{{ page_number }}</strong>
        {% else %}
        <a href="?page={{ page_number }}{{ GET_string }}"
        title="{% trans "Entries page" %} {{ page_number }}">{{ page_number }}</a>
        {% endifequal%}
    </li>
    {% endfor %}

    {% if middle %}
    <li class="unavailable">&hellip;</li>
    {% for page_number in middle %}
    <li class="page {% ifequal page.number page_number %}current unavailable{% endifequal %}">
        {% ifequal page.number page_number %}
        <strong>{{ page_number }}</strong>
        {% else %}
        <a href="?page={{ page_number }}{{ GET_string }}"
        title="{% trans "Entries page" %} {{ page_number }}">{{ page_number }}</a>
        {% endifequal%}
    </li>
    {% endfor %}
    {% endif %}

    {% if end %}
    <li class="unavailable">&hellip;</li>
    {% for page_number in end %}
    <li class="page {% ifequal page.number page_number %}current unavailable{% endifequal %}">
        {% ifequal page.number page_number %}
        <strong>{{ page_number }}</strong>
        {% else %}
        <a href="?page={{ page_number }}{{ GET_string }}"
        title="{% trans "Entries page" %} {{ page_number }}">{{ page_number }}</a>
        {% endifequal%}
    </li>
    {% endfor %}
    {% endif %}

    {% if page.has_next %}
    <li class="arrow next">
        <a href="?page={{ page.next_page_number }}{{ GET_string }}"
        title="{% trans "More old entries" %}">&raquo;</a>
    </li>
    {% endif %}
    </ul>
</div>