{% extends "registration/base.html" %}
{% load i18n %}
{% load url from future %}

{% block base_content %}
    <div class="row">
        <div class="six columns centered">
            <h2>{% trans "Password reset" %}</h2>

            <p>{% trans "Password reset successfully" %}</p>

            <p>{% trans "Now you can" %} <a href="{% url 'auth_login' %}">{% trans "Log in" %}</a></p>
        </div>
    </div>
{% endblock %}
