{% load i18n %}
<ul class="nav-bar">
  {% for category in categories %}
  <li{% if category.slug == context_category.slug %} class="active"{% endif %}>
    <a href="{{ category.get_absolute_url }}">{{ category }}</a>
  </li>
  {% empty %}
  <li>
    {% trans "No categories yet" %}
  </li>
  {% endfor %}
</ul>

