{% extends "admin/cms/page/plugin_change_form.html" %}
{% comment %}This template overwriting is needed to load the FB_CKEditor that is needed 
to plug Filebrowser with CKEditor.
Also we take advantage of this to add a line code to avoid self closing tag because we 
want to enforce HTML5 again XHTML.
And finally, we includes some javascripts frontend needed to have a better rendering.{% endcomment %}
{% block extrastyle %}{{ block.super }}<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/minimal.css" />
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}ckeditor/editor.css" />{% endblock %}

{% block extrahead %}{{ block.super }}
<script type="text/javascript" src="{{ STATIC_URL }}filebrowser/js/FB_CKEditor.js"></script>
<script type="text/javascript" src="{{ STATIC_URL }}js/jquery/addons.js"></script>
<script type="text/javascript">
//<![CDATA[
//     CKEDITOR.extraAllowedContent = { a: {attributes: 'boo'} };
    CKEDITOR.on( 'instanceReady', function( ev ) {% templatetag openvariable %}ev.editor.dataProcessor.writer.selfClosingEnd = '>';{% templatetag closevariable %});
    $(document).ready(function() {
        $('#content-main img.background').swapImageToBackground();
    });
//]]>
</script>
{% endblock %}
