/*
 * Stylesheets for Zinnia with Foundation 3
 */
.weblog{
    padding-top: 25px;
    padding-bottom: 25px;
    
    hr{
        border-color: #000000;
        border-style: solid;
        border-width: 1px 0 0;
        clear: both;
        height: 0;
        margin: 22px 0 21px;
        @include box-shadow(#404040 0 0 4px);
    }
    
    .entry-title{
        font-weight: 600;
        
        h2{
            color: #000000;
            a{ color: inherit; }
        }
    }
    h2.entry-title,
    .entry-info{
        color: #000000;
        a{ color: inherit; }
    }
    
    .entry-image {
        float: left;
        margin: 5px 10px 5px 0;
        
        p{
            margin: 0;
        }
    }
}