/*
CSS for CKEditor content

Copyright (c) 2003-2012, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.html or http://ckeditor.com/license

Taken from the original ckeditor/content.css and adapted for Emencia

Note that this does not includes the whole Foundation SCSS because it works on 
"position:relative" which is a blocking style rule for the useful "magicline" ckeditor 
plugin. But we include some SCSS from Foundation's components.
*/
@import "settings";
@import "compass/css3";
@import "foundation/settings";

@import "components/font-awesome";
@import "mixins/base";

// Used within ".brand"
// @import url(http://fonts.googleapis.com/css?family=Radley);

body
{
    /* Font */
    font-family: sans-serif, Arial, Verdana, "Trebuchet MS";
    font-size: 12px;

    /* Text color */
    color: #333;

    /* Remove the background color to make it transparent */
    background-color: #fff;

    margin: 20px;
}

.cke_editable
{
    font-size: 13px;
    line-height: 1.6em;
}

blockquote
{
    font-style: italic;
    font-family: Georgia, Times, "Times New Roman", serif;
    padding: 2px 0;
    border-style: solid;
    border-color: #ccc;
    border-width: 0;
}

.cke_contents_ltr blockquote
{
    padding-left: 20px;
    padding-right: 8px;
    border-left-width: 5px;
}

.cke_contents_rtl blockquote
{
    padding-left: 8px;
    padding-right: 20px;
    border-right-width: 5px;
}

a
{
    color: #0782C1;
}

ol,ul,dl
{
    /* IE7: reset rtl list margin. (#7334) */
    *margin-right: 0px;
    /* preserved spaces for list items with text direction other than the list. (#6249,#8049)*/
    padding: 0 40px;
}

h1,h2,h3,h4,h5,h6
{
    font-weight: normal;
    line-height: 1.2em;
}

hr
{
    border: 0px;
    border-top: 1px solid #ccc;
}

img{
    max-width: 100%;
}

img.right {
    border: 1px solid #ccc;
    float: right;
    margin-left: 15px;
    padding: 5px;
}

img.left {
    border: 1px solid #ccc;
    float: left;
    margin-right: 15px;
    padding: 5px;
}

img:hover {
    opacity: .9;
    filter: alpha(opacity = 90);
}

/* Here comes styles addons and overwrites */
$bodyPadding: 10px;
.cke_editable{
    margin: auto;
    width: ($rowWidth+($bodyPadding*2));
    max-width: 100%;
    padding: $bodyPadding;
    
    @include foundation-content-base;
}

.text-left{
    text-align: left;
}
.text-right{
    text-align: right;
}
.text-center{
    text-align: center;
}

@include global-addons;
