/*
 * Minimal CSS, contain all the content layout but not the header nor the
 * footer. Used in djangocms page render in admin
 */
@import "settings";
@import "common/resolutions";

// ----------------------------------------
// Import specific parts of Foundation by commenting the import "foundation"
// and uncommenting what you want below. You must uncomment the following if customizing
@import "compass/css3";
@import "foundation/settings";

// Must include the grid for any responsiveness
@import "foundation/components/grid";

// Control which components you get if customizing
@import "foundation/components/buttons";
@import "foundation/components/tabs";
@import "foundation/components/top-bar";
// @import "foundation/components/modules/navbar";
@import "foundation/components/orbit";
// @import "foundation/components/modules/reveal";
// @import "foundation/components/modules/offcanvas";

// Media Queries Overrides
//@import "foundation/components/mqueries";

@import "components/font-awesome"; // Various icon with customized font
@import "components/flags"; // Lang flags sprites
@import "mixins/base";
@import "common/resolutions";
@import "common/addons";

#content-main{
    @include foundation-content-base;
    @import "content";
}
