<div class="row row-fluid" id="isocontainer">
    <div id="isospinner" class="spinner-block"></div>
    <div id="isogrid" style="visibility:hidden;">
        <div class="grid-base"></div>
        {% for ressource_item in feed_ressources %}{% with ressource_item.get_unified_render as ressource %}
        <div class="grid-item{% if ressource.css_classes %} {{ ressource.css_classes }}{% endif %}">
        {% if ressource.url %}<a href="{{ ressource.url }}">{% endif %}
            <div class="containItem"{% if ressource.image %} style="background-image:url('{{ ressource.image }}')"{% endif %}>
                <section class="contentBlock">
                    <div class="contentInfo">
                    {% if ressource.title %}<h2>{{ ressource.title }}</h2>{% endif %}
                    {% if ressource.description %}<p>{{ ressource.description|safe|linebreaksbr }}</p>{% endif %}
                    {% if ressource.button %}<p>
                        <a href="{{ ressource.button.url }}" class="medium button go {{ ressource.button.color }}">{{ ressource.button.label }}<span class="icon-typo">&gt;</span></a>
                    </p>{% endif %}
                    </div>
                    {% if ressource.has_subblock %}<div class="block_posted">
                        <h5>{{ ressource.author }}</h5>
                        {{ ressource.date|date:"d N" }}
                    </div>{% endif %}
                </section>
            </div>
            {% if ressource.url %}</a>{% endif %}
        </div>
        {% endwith %}{% endfor %}
    </div>
</div>
