<div class="row index-intro-2 divider">
    <img src="http://placehold.it/1000x346" class="background" alt="">
    <div class="content">
        <div class="medium-6 columns black-wrap">
            <h2>Title 1</h2>
            <p>Etiam blandit libero eget nisi dapibus gravida! Quisque euismod ut tellus in ornare. Cras convallis, est eget aliquam aliquet, massa dui pulvinar neque.</p>
            <p>Donec lacinia ultricies eros a pellentesque. In nec dapibus quam, sit amet adipiscing lorem. Praesent consequat nunc pharetra.</p>
            <p class="text-right"><a class="button radius secondary small" href="">En savoir plus</a></p>
        </div>
    </div>
</div>
